==> junta-0.2.15.tar.gz: junta-0.2.15/setup.py <==
#!/usr/bin/env python
# coding: utf-8

import glob
import os
import shutil
import sys
from distutils.core import setup


settings_path = '/etc/junta'
settings_files = ['agent.json', 'server.json']

setup(
    name='junta',
    version='0.2.15',
    packages=['junta', 'junta.server', 'junta.agent'],
    package_dir={'junta': '', 'junta.server': 'server', 'junta.agent': 'agent'},
    data_files=[
        ('/etc/init', ['setup/junta-agent.conf', 'setup/junta-server.conf']),
        ('/etc/junta', ['setup/default_' + name for name in settings_files]),
        ('/usr/share/junta', [])
        ],
    package_data={'junta.server': ['static/images/*', 'static/*.*', 'templates/*', 'backend/*', 'users/*']},
    author='iVideon',
    author_email='support@ivideon.ru',
    url='https://bitbucket.org/ivideon/junta',
    install_requires=['setuptools', 'tornado', 'ws4py==0.1.4', 'pymongo', 'django']
    )

if 'install' in sys.argv:
    for f in settings_files:
        if not os.path.isfile(os.path.join(settings_path, f)):
            try:
                shutil.copyfile(os.path.join(settings_path, 'default_' + f), os.path.join(settings_path, f))
            except Exception as e:
                print "Error: can not copy config file. Exception: {}.".format(e)
              
    import os
    import subprocess
    import sys
    import time
            
    def run_shell_command(command, err_to_dev_null=False):
        try:
            if err_to_dev_null:
                err = open('dev/null', 'w')
            else:
                err = sys.stderr
            p = subprocess.Popen(command, shell=True, stdin=subprocess.PIPE, stderr=err, env=os.environ)
            p.communicate("no")               
            p.wait()
            returncode = p.returncode
            if returncode != 0:
                return False
            return True
        except Exception as e:
            return False
    
    def set_default_user():
        import imp
        sys.path.append('/usr/local/lib/python2.7/dist-packages/junta/server')
        imp.find_module('settings')
        #
        os.environ.update({'DJANGO_SETTINGS_MODULE': 'server.settings'})
        import settings
        
        from django.contrib.auth.models import User
        from django.core.management import execute_manager
        
        u = User.objects.get(username__exact='ivideon')
        u.set_password('ivideon')
        u.save()
    
    run_shell_command("echo '\nInstalling GIT'")
    run_shell_command("sudo apt-get install git")
    
    run_shell_command("echo '\nInstalling sockjs from github'")
    run_shell_command("sudo pip install git+https://github.com/MrJoes/sockjs-tornado.git")
    
    run_shell_command("echo '\nInstalling database for django'")
    run_shell_command("sudo python /usr/local/lib/python2.7/dist-packages/junta/server/manage.py syncdb")
    if run_shell_command("sudo python server/manage.py createsuperuser --username ivideon --email junta@ivideon.ru --noinput", True):
        set_default_user()
    
    run_shell_command("echo '\nInstallation ends.\n To start server run command: sudo start junta-server'")

#sudo python setup.py sdist upload

==> junta-0.2.16.tar.gz: junta-0.2.16/setup.py <==
#!/usr/bin/env python
# coding: utf-8

import glob
import os
import shutil
import sys
from distutils.core import setup


settings_path = '/etc/junta'
settings_files = ['agent.json', 'server.json']

setup(
    name='junta',
    version='0.2.16',
    packages=['junta', 'junta.server', 'junta.agent'],
    package_dir={'junta': '', 'junta.server': 'server', 'junta.agent': 'agent'},
    data_files=[
        ('/etc/init', ['setup/junta-agent.conf', 'setup/junta-server.conf']),
        ('/etc/junta', ['setup/default_' + name for name in settings_files]),
        ('/usr/share/junta', [])
        ],
    package_data={'junta.server': ['static/images/*', 'static/*.*', 'templates/*', 'installations/*', 'users/*', 'machines/*', 'recipes/*']},
    author='iVideon',
    author_email='support@ivideon.ru',
    url='https://bitbucket.org/ivideon/junta',
    install_requires=['setuptools', 'tornado', 'ws4py==0.1.4', 'pymongo', 'django']
    )

if 'install' in sys.argv:
    for f in settings_files:
        if not os.path.isfile(os.path.join(settings_path, f)):
            try:
                shutil.copyfile(os.path.join(settings_path, 'default_' + f), os.path.join(settings_path, f))
            except Exception as e:
                print "Error: can not copy config file. Exception: {}.".format(e)
              
    import os
    import subprocess
    import sys
    import time
            
    def run_shell_command(command, err_to_dev_null=False):
        try:
            if err_to_dev_null:
                err = open('dev/null', 'w')
            else:
                err = sys.stderr
            p = subprocess.Popen(command, shell=True, stdin=subprocess.PIPE, stderr=err, env=os.environ)
            p.communicate("no")               
            p.wait()
            returncode = p.returncode
            if returncode != 0:
                return False
            return True
        except Exception as e:
            return False
    
    def set_default_user():
        import imp
        sys.path.append('/usr/local/lib/python2.7/dist-packages/junta/server')
        imp.find_module('settings')
        #
        os.environ.update({'DJANGO_SETTINGS_MODULE': 'server.settings'})
        import settings
        
        from django.contrib.auth.models import User
        from django.core.management import execute_manager
        
        u = User.objects.get(username__exact='ivideon')
        u.set_password('ivideon')
        u.save()
    
    run_shell_command("echo '\nInstalling GIT'")
    run_shell_command("sudo apt-get install git")
    
    run_shell_command("echo '\nInstalling sockjs from github'")
    run_shell_command("sudo pip install git+https://github.com/MrJoes/sockjs-tornado.git")
    
    run_shell_command("echo '\nInstalling database for django'")
    run_shell_command("sudo python /usr/local/lib/python2.7/dist-packages/junta/server/manage.py syncdb")
    if run_shell_command("sudo python server/manage.py createsuperuser --username ivideon --email junta@ivideon.ru --noinput", True):
        set_default_user()
    
    run_shell_command("echo '\nInstallation ends.\n To start server run command: sudo start junta-server'")

#sudo python setup.py sdist upload
